Module: Google::Cloud::PrivateCatalog
- Defined in:
- lib/google/cloud/private_catalog.rb,
lib/google/cloud/private_catalog/version.rb
Constant Summary collapse
- VERSION =
"0.8.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.private_catalog| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-private_catalog library.
-
.private_catalog(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PrivateCatalog.
-
.private_catalog_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PrivateCatalog service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.private_catalog| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-private_catalog library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
167 168 169 170 171 |
# File 'lib/google/cloud/private_catalog.rb', line 167 def self.configure yield ::Google::Cloud.configure.private_catalog if block_given? ::Google::Cloud.configure.private_catalog end |
.private_catalog(version: :v1beta1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for PrivateCatalog.
By default, this returns an instance of
Google::Cloud::PrivateCatalog::V1beta1::PrivateCatalog::Client
for a gRPC client for version V1beta1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the PrivateCatalog service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PrivateCatalog service. You can determine whether the method will succeed by calling private_catalog_available?.
About PrivateCatalog
PrivateCatalog allows catalog consumers to retrieve Catalog, Product
and Version resources under a target resource context.
Catalog is computed based on the [Association][]s linked to the target
resource and its ancestors. Each association's
[google.cloud.privatecatalogproducer.v1beta.Catalog][] is transformed into a
Catalog. If multiple associations have the same parent
[google.cloud.privatecatalogproducer.v1beta.Catalog][], they are
de-duplicated into one Catalog. Users must have
cloudprivatecatalog.catalogTargets.get IAM permission on the resource
context in order to access catalogs. Catalog contains the resource name and
a subset of data of the original
[google.cloud.privatecatalogproducer.v1beta.Catalog][].
Product is child resource of the catalog. A Product contains the resource
name and a subset of the data of the original
[google.cloud.privatecatalogproducer.v1beta.Product][].
Version is child resource of the product. A Version contains the resource
name and a subset of the data of the original
[google.cloud.privatecatalogproducer.v1beta.Version][].
95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/google/cloud/private_catalog.rb', line 95 def self.private_catalog version: :v1beta1, transport: :grpc, &block require "google/cloud/private_catalog/#{version.to_s.downcase}" package_name = Google::Cloud::PrivateCatalog .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::PrivateCatalog.const_get(package_name).const_get(:PrivateCatalog) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.private_catalog_available?(version: :v1beta1, transport: :grpc) ⇒ boolean
Determines whether the PrivateCatalog service is supported by the current client. If true, you can retrieve a client object by calling private_catalog. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PrivateCatalog service, or if the versioned client gem needs an update to support the PrivateCatalog service.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/google/cloud/private_catalog.rb', line 119 def self.private_catalog_available? version: :v1beta1, transport: :grpc require "google/cloud/private_catalog/#{version.to_s.downcase}" package_name = Google::Cloud::PrivateCatalog .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::PrivateCatalog.const_get package_name return false unless service_module.const_defined? :PrivateCatalog service_module = service_module.const_get :PrivateCatalog if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |